import os
import matplotlib.pyplot as plt
import pandas as pd
from sklearn.linear_model import LinearRegression
import numpy as np

# read csv data++++++++++++++++++++++++++++++++++++++++++++++
def read_csv(basefolder, filename, index_column = 'Date'):
    file = os.path.join(basefolder, filename)
    return pd.read_csv(file ,index_col=index_column , parse_dates=True)
# Read csv data, use ‘Date’ as index
#                         IWV
#Date
#1995-01-16 13:00:00   7.3736
#1995-02-14 23:00:00  10.2056
#1995-03-16 10:00:00   7.7730
# resample+++++++++++++++++++++++++++++++++++++++++++++++++++
def resample_dataserie(ds, freq='Y'):
    return ds.resample(freq).mean()
# Resample the data by years
#                  IWV
#Date
#1995-12-31  14.404875
#1996-12-31  13.629292
#1997-12-31  14.065108
#linear regression+++++++++++++++++++++++++++++++++++++++++++$
def do_linear_regression(resampled_ds):
    model = LinearRegression() # Linear regression function
    Date=resampled_ds.index.year# Get the year of resampled 'Date'
    IWV=resampled_ds.IWV.values# Resampled 'IWV'

    Date=np.array(Date)
    x=Date.reshape(-1,1)# Transform input data: LinearRegression need the input data is array and 2D

    model.fit(x,IWV)# Fitting
    y_pred = model.predict(x) # Get results: predicted response
    print('slope:',model.coef_)


    resampled_ds['fitted']=y_pred# write data to column
    return resampled_ds

if __name__ == "__main__":
    folder =''
    filename = 'iwv_Bern.csv'
    IWV_series = read_csv(folder, filename)
    IWV_yearly = resample_dataserie(IWV_series, freq='Y')

    IWV_fit = do_linear_regression(IWV_yearly)


    #plots+++++++++++++++++++++++++++++++++++++++++++++++++++++++
    fig, axs= plt.subplots(1,1)
    plt.ylabel('IWV(mm)')
    IWV_series.plot(ax=axs)
    IWV_fit['IWV'].plot(ax=axs)#The same x-axis, plotting data in DataFrame format
    IWV_fit['fitted'].plot(ax=axs)
    plt.show()





